---
name: Bug Report
about: Report a bug in molecule-kubevirt
title: ''
labels: bug
assignees: ''

---
<!-- Make sure that you read carefully README.md and KubeVirt install.
-->

**What happened**:
A clear and concise description of what the bug is.

**What you expected to happen**:
A clear and concise description of what you expected to happen.

**How to reproduce it (as minimally and precisely as possible)**:
Steps to reproduce the behavior.

**Additional context**:
Add any other context about the problem here.

**Environment**:
- ansible --vesion: N/A
- molecule --version: N/A
- KubeVirt version (use `virtctl version`): N/A
- Kubernetes version (use `kubectl version`): N/A
- OS (e.g. from /etc/os-release): N/A
- Kernel (e.g. `uname -a`): N/A
- Install tools: N/A
- Others: N/A
